@@ -2,9 +2,7 @@ from django.contrib import admin
 
 from .models import QuillPost
 
-__all__ = (
-    'QuillPostAdmin',
-)
+__all__ = ("QuillPostAdmin",)
 
 
 @admin.register(QuillPost)
